Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(95)

Unified Diff: chrome/common/chrome_notification_types.h

Issue 11824050: InstantExtended: Committed NTP (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Undo to fix blacklisting. Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_browser.gypi ('k') | content/browser/web_contents/web_contents_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_notification_types.h
diff --git a/chrome/common/chrome_notification_types.h b/chrome/common/chrome_notification_types.h
index 50784b6b4932523348e48c025c62127f5228ee53..2fb5e071e88bc173fe2d73bd15d9260b5cdb6034 100644
--- a/chrome/common/chrome_notification_types.h
+++ b/chrome/common/chrome_notification_types.h
@@ -1101,9 +1101,13 @@ enum NotificationType {
// containing the committed preview.
NOTIFICATION_INSTANT_COMMITTED,
- // Sent when the Instant loader determines whether the page supports the
+ // Sent when the Instant Controller determines whether the overlay supports
+ // the Instant API or not.
+ NOTIFICATION_INSTANT_OVERLAY_SUPPORT_DETERMINED,
+
+ // Sent when the Instant Controller determines whether the NTP supports the
// Instant API or not.
- NOTIFICATION_INSTANT_SUPPORT_DETERMINED,
+ NOTIFICATION_INSTANT_NTP_SUPPORT_DETERMINED,
// Sent when the CaptivePortalService checks if we're behind a captive portal.
// The Source is the Profile the CaptivePortalService belongs to, and the
« no previous file with comments | « chrome/chrome_browser.gypi ('k') | content/browser/web_contents/web_contents_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698